Generate second gradient — BAGO 0.0.1 documentation

# Generate second gradient

Note

When the second gradient is not specified by user, it is generated.

computeSecondGradient(parameters, model)

  Calculate the second gradient to run.

  Parameters:

    - parameters – dict. Global parameters.

    - model – a `gpModel` object. Gaussian process model.

  Returns:

    numpy array. The second gradient.

To use this function:

    # You need a gpModel object (model)

    computeSecondGradient(parameters, model)